import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import Responsive from 'react-responsive';
import { injectIntl, intlShape } from '@edx/frontend-platform/i18n';
import { AppContext } from '@edx/frontend-platform/react';
import { ensureConfig } from '@edx/frontend-platform/config';
import DesktopHeader from './DesktopHeader';
import MobileHeader from './MobileHeader';
import LogoImg from './logo.png';
import messages from './Header.messages';
ensureConfig(['LMS_BASE_URL', 'LOGOUT_URL', 'LOGIN_URL', 'SITE_NAME'], 'Header component');

function Header(_ref) {
  var intl = _ref.intl,
      renderSearch = _ref.renderSearch,
      mainMenuType = _ref.mainMenuType;

  var _useContext = useContext(AppContext),
      authenticatedUser = _useContext.authenticatedUser,
      config = _useContext.config;

  var mainMenu = [{
    type: 'item',
    href: "".concat(config.MARKETING_SITE_BASE_URL, "/courses"),
    content: intl.formatMessage(messages['header.links.courses'])
  }, {
    type: 'item',
    href: "".concat(config.MARKETING_SITE_BASE_URL, "/programs"),
    content: intl.formatMessage(messages['header.links.programs'])
  }, {
    type: 'item',
    href: "".concat(config.MARKETING_SITE_BASE_URL, "/lives"),
    content: intl.formatMessage(messages['header.links.lives'])
  }];
  var userMenu = authenticatedUser === null ? [] : [{
    type: 'item',
    href: "".concat(config.LMS_BASE_URL, "/dashboard"),
    content: intl.formatMessage(messages['header.user.menu.dashboard'])
  }, {
    type: 'item',
    href: "".concat(config.LMS_BASE_URL, "/u/").concat(authenticatedUser.username),
    content: intl.formatMessage(messages['header.user.menu.profile'])
  }, {
    type: 'item',
    href: "".concat(config.LMS_BASE_URL, "/account/settings"),
    content: intl.formatMessage(messages['header.user.menu.account.settings'])
  }, {
    type: 'item',
    href: config.LOGOUT_URL,
    content: intl.formatMessage(messages['header.user.menu.logout'])
  }];
  var loggedOutItems = [{
    type: 'item',
    href: config.LOGIN_URL,
    content: intl.formatMessage(messages['header.user.menu.login'])
  }, {
    type: 'item',
    href: "".concat(config.LMS_BASE_URL, "/register"),
    content: intl.formatMessage(messages['header.user.menu.register'])
  }];
  var props = {
    logo: LogoImg,
    logoAltText: config.SITE_NAME,
    siteName: config.SITE_NAME,
    logoDestination: "".concat(config.MARKETING_SITE_BASE_URL),
    loggedIn: authenticatedUser !== null,
    username: authenticatedUser !== null ? authenticatedUser.username : null,
    avatar: authenticatedUser !== null ? authenticatedUser.avatar : null,
    mainMenu: mainMenu,
    userMenu: userMenu,
    loggedOutItems: loggedOutItems,
    renderSearch: renderSearch,
    mainMenuType: mainMenuType
  };
  return React.createElement(React.Fragment, null, React.createElement(Responsive, {
    maxWidth: 768
  }, React.createElement(MobileHeader, props)), React.createElement(Responsive, {
    minWidth: 769
  }, React.createElement(DesktopHeader, props)));
}

Header.propTypes = {
  intl: intlShape.isRequired,
  renderSearch: PropTypes.func,
  mainMenuType: PropTypes.string
};
Header.defaultProps = {
  renderSearch: null,
  mainMenuType: null
};
export default injectIntl(Header);
//# sourceMappingURL=Header.js.map